//--------- start footer Area -------------//
.footer-area {
    background-color: #222222;
}

h6 {
    color: #fff;
    margin-bottom: 25px;
    font-size: 18px;
    font-weight: 600;
}

.copy-right-text {
    i,
    a {
        color: $primary-color;
    }
}

.instafeed {
    margin: -5px;
    li {
        overflow: hidden;
        width: 25%;
        img {
            margin: 5px;
        }
    }
}

.footer-social {
    a {
        padding-right: 25px;
        @include transition();
        &:hover {
            i {
                color: $primary-color;
            }
        }
    }
    i {
        color: #cccccc;
        @include transition();
    }
    @include media-breakpoint-down(md) {
        text-align: left;
    }
}

.single-footer-widget {
    input {
        border: none;
        width: 80%;
        font-weight: 300;
        background: #191919;
        color: #777;
        padding-left: 20px;
        border-radius: 0;
        font-size: 14px;
        &:focus {
            background-color: #191919;
        }
    }
    .bb-btn {
        background: $primary-color;
        color: #fff;
        font-weight: 300;
        border-radius: 0;
        z-index: 9999;
        cursor: pointer;
    }
    .info {
        position: absolute;
        margin-top: 20%;
        color: #fff;
        font-size: 12px;
        &.valid {
            color: green;
        }
        &.error {
            color: red;
        }
    }
    .click-btn {
        background: $primary-color;
        color: #fff;
        border-radius: 0;
        border-top-left-radius: 0px;
        border-bottom-left-radius: 0px;
        padding: 6px 12px;
        border: 0;
        i {
            color: #fff;
        }
    }
    ::-moz-selection {
        /* Code for Firefox */
        background-color: #191919 !important;
        color: $text-color;
    }
    ::selection {
        background-color: #191919 !important;
        color: $text-color;
    }
    ::-webkit-input-placeholder {
        /* WebKit, Blink, Edge */
        color: $text-color;
        font-weight: 300;
    }
    :-moz-placeholder {
        /* Mozilla Firefox 4 to 18 */
        color: $text-color;
        opacity: 1;
        font-weight: 300;
    }
    ::-moz-placeholder {
        /* Mozilla Firefox 19+ */
        color: $text-color;
        opacity: 1;
        font-weight: 300;
    }
    :-ms-input-placeholder {
        /* Internet Explorer 10-11 */
        color: $text-color;
        font-weight: 300;
    }
    ::-ms-input-placeholder {
        /* Microsoft Edge */
        color: $text-color;
        font-weight: 300;
    }
    @include media-breakpoint-down(md) {
        margin-bottom: 30px;
    }
}

.footer-text {
    padding-top: 80px;
    @media(max-width: 991px) {
		padding-top: 0px;
	}
    p {
        margin-bottom: 0;
    }
    a,
    i {
        color: $primary-color;
    }
}

//--------- end footer Area -------------//